@@ -4,12 +4,6 @@
 #'  recipe step that will create a two-level factor from a single
 #'  dummy variable.
 #' @inheritParams step_center
-#' @inherit step_center return
-#' @param ... Selector functions that choose which variables will
-#'  be converted. See [selections()] for more details. For
-#'  the `tidy` method, these are not currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
 #' @param levels A length 2 character string that indicates the
 #'  factor levels for the 1's (in the first position) and the zeros
 #'  (second)
@@ -17,10 +11,7 @@
 #' 1's, be the factor reference level?
 #' @param columns A vector with the selected variable names. This
 #'  is `NULL` until computed by [prep.recipe()].
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  columns that will be affected).
+#' @template step-return
 #' @details This operation may be useful for situations where a
 #'  binary piece of information may need to be represented as
 #'  categorical instead of numeric. For example, naive Bayes models
@@ -28,10 +19,11 @@
 #'  distribution is modeled instead of a Gaussian probability
 #'  density of numeric binary data. Note that the numeric data is
 #'  only verified to be numeric (and does not count levels).
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept dummy_variables
-#' @concept factors
+#'
+#'  When you [`tidy()`] this step, a tibble with column `terms` (the
+#'  columns that will be affected) is returned.
+#'
+#' @family dummy variable and encoding steps
 #' @export
 #' @examples
 #' library(modeldata)
@@ -94,7 +86,7 @@ step_bin2factor_new <-
 
 #' @export
 prep.step_bin2factor <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- recipes_eval_select(x$terms, training, info)
   if (length(col_names) < 1)
     rlang::abort("The selector should only select at least one variable")
   if (any(info$type[info$variable %in% col_names] != "numeric"))
@@ -132,8 +124,7 @@ print.step_bin2factor <-
   }
 
 
-#' @rdname step_bin2factor
-#' @param x A `step_bin2factor` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_bin2factor <- function(x, ...) {
   res <-simple_terms(x, ...)
