@@ -3,28 +3,13 @@
 #' `step_cut()` creates a *specification* of a recipe step that cuts a numeric
 #'  variable into a factor based on provided boundary values
 #'
-#' @param recipe A recipe object. The step will be added to the sequence of
-#'  operations for this recipe.
-#' @param ... One or more selector functions to choose which variables are
-#'  affected by the step. See [selections()] for more details. For the `tidy`
-#'  method, these are not currently used.
-#' @param role Not used by this step since no new variables are created.
-#' @param trained A logical to indicate if the quantities for preprocessing
-#'  have been estimated.
+#' @inheritParams step_center
 #' @param breaks A numeric vector with at least one cut point.
 #' @param include_outside_range Logical, indicating if values outside the
 #'  range in the train set should be included in the lowest or highest bucket.
 #'  Defaults to `FALSE`, values outside the original range will be set to `NA`.
-#' @param skip A logical. Should the step be skipped when the recipe is baked
-#'  by [bake.recipe()]? While all operations are baked when [prep.recipe()] is
-#'  run, some operations may not be able to be conducted on new data (e.g.
-#'  processing the outcome variable(s)). Care should be taken when using `skip =
-#'  TRUE` as it may affect the computations for subsequent operations
-#' @param id A character string that is unique to this step to identify it.
-#' @return An updated version of `recipe` with the new step added to the
-#'  sequence of existing steps (if any).
-#' @keywords datagen
-#' @concept preprocessing
+#' @template step-return
+#' @family discretization steps
 #' @export
 #' @details Unlike the `base::cut()` function there is no need to specify the
 #'  min and the max values in the breaks. All values before the lowest break
@@ -111,7 +96,7 @@ step_cut_new <-
   }
 
 prep.step_cut <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
 
   check_type(training[, col_names])
 
@@ -209,8 +194,7 @@ print.step_cut <-
     invisible(x)
   }
 
-#' @rdname step_cut
-#' @param x A `step_cut` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_cut <- function(x, ...) {
   if (is_trained(x)) {
