@@ -5,25 +5,16 @@
 #'  function.
 #'
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables are affected by the step. See [selections()]
-#'  for more details.  For the `tidy` method, these are not
-#'  currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
 #' @param func A character value for the function. Valid values
 #'  are "sin", "cos", or "tan".
 #' @param inverse A logical: should the inverse function be used?
 #' @param columns A character string of variable names that will
 #'  be populated (eventually) by the `terms` argument.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  columns that will be affected), `inverse`, and `func`.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept transformation_methods
+#' @template step-return
+#' @family individual transformation steps
 #' @export
+#' @details When you [`tidy()`] this step, a tibble with columns `terms` (the
+#'  columns that will be affected), `inverse`, and `func` is returned.
 #' @examples
 #' set.seed(313)
 #' examples <- matrix(rnorm(40), ncol = 2)
@@ -42,10 +33,6 @@
 #'
 #' tidy(cos_trans, number = 1)
 #' tidy(cos_obj, number = 1)
-#' @seealso [step_logit()] [step_invlogit()]
-#'   [step_log()]  [step_sqrt()] [recipe()]
-#'   [prep.recipe()] [bake.recipe()]
-
 step_hyperbolic <-
   function(recipe,
            ...,
@@ -91,7 +78,7 @@ step_hyperbolic_new <-
 
 #' @export
 prep.step_hyperbolic <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names])
 
   step_hyperbolic_new(
@@ -129,8 +116,7 @@ print.step_hyperbolic <-
     invisible(x)
   }
 
-#' @rdname step_hyperbolic
-#' @param x A `step_hyperbolic` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_hyperbolic <- function(x, ...) {
   out <- simple_terms(x, ...)
