@@ -1,21 +1,10 @@
-#' Imputation via K-Nearest Neighbors
+#' Impute via k-nearest neighbors
 #'
 #' `step_impute_knn` creates a *specification* of a recipe step that will
 #'  impute missing data using nearest neighbors.
 #'
+#' @inheritParams step_impute_bag
 #' @inheritParams step_center
-#' @inherit step_center return
-#' @param ... One or more selector functions to choose variables. For
-#'  `step_impute_knn`, this indicates the variables to be imputed. When used
-#'  with `imp_vars`, the dots indicate which variables are used to predict the
-#'  missing data in each variable. See [selections()] for more details. For the
-#'  `tidy` method, these are not currently used.
-#' @param role Not used by this step since no new variables are created.
-#' @param impute_with A call to `imp_vars` to specify which variables are used
-#'  to impute the variables that can include specific variable names separated
-#'  by commas or different selectors (see [selections()]). If a column is
-#'  included in both lists to be imputed and to be an imputation predictor, it
-#'  will be removed from the latter and not used to impute itself.
 #' @param neighbors The number of neighbors.
 #' @param options A named list of options to pass to [gower::gower_topn()].
 #'  Available options are currently `nthread` and `eps`.
@@ -24,13 +13,8 @@
 #'  is trained by [prep.recipe()].
 #' @param columns The column names that will be imputed and used for
 #'  imputation. This is `NULL` until the step is trained by [prep.recipe()].
-#' @return An updated version of `recipe` with the new step added to the
-#'  sequence of existing steps (if any). For the `tidy` method, a tibble with
-#'  columns `terms` (the selectors or variables for imputation), `predictors`
-#'  (those variables used to impute), and `neighbors`.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept imputation
+#' @template step-return
+#' @family imputation steps
 #' @export
 #' @details The step uses the training set to impute any other data sets. The
 #'  only distance function available is Gower's distance which can be used for
@@ -46,6 +30,10 @@
 #' It is possible that missing values will still occur after imputation if a
 #'  large majority (or all) of the imputing variables are also missing.
 #'
+#' When you [`tidy()`] this step, a tibble with
+#'  columns `terms` (the selectors or variables for imputation), `predictors`
+#'  (those variables used to impute), and `neighbors` is returned.
+#'
 #' As of `recipes` 0.1.16, this function name changed from `step_knnimpute()`
 #'    to `step_impute_knn()`.
 #'
@@ -152,7 +140,7 @@ step_knnimpute <-
            columns = NULL,
            skip = FALSE,
            id = rand_id("impute_knn")) {
-    lifecycle::deprecate_soft(
+    lifecycle::deprecate_warn(
       when = "0.1.16",
       what = "recipes::step_knnimpute()",
       with = "recipes::step_impute_knn()"
@@ -217,6 +205,7 @@ prep.step_impute_knn <- function(x, training, info = NULL, ...) {
 }
 
 #' @export
+#' @keywords internal
 prep.step_knnimpute <- prep.step_impute_knn
 
 nn_index <- function(miss_data, ref_data, vars, K, opt) {
@@ -266,6 +255,7 @@ bake.step_impute_knn <- function(object, new_data, ...) {
         pred_vals <-
           apply(nn_ind, 2, nn_pred, dat = object$ref_data[imp_var_complete, imp_var])
         pred_vals <- cast(pred_vals, object$ref_data[[imp_var]])
+        new_data[[imp_var]] <- vec_cast(new_data[[imp_var]], pred_vals)
         new_data[missing_rows, imp_var] <- pred_vals
       }
     }
@@ -274,6 +264,7 @@ bake.step_impute_knn <- function(object, new_data, ...) {
 }
 
 #' @export
+#' @keywords internal
 bake.step_knnimpute <- bake.step_impute_knn
 
 #' @export
@@ -287,18 +278,18 @@ print.step_impute_knn <-
   }
 
 #' @export
+#' @keywords internal
 print.step_knnimpute <- print.step_impute_knn
 
-#' @rdname step_impute_knn
-#' @param x A `step_impute_knn` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_impute_knn <- function(x, ...) {
   if (is_trained(x)) {
     res <- purrr::map_df(x$columns,
                          function(x)
                            data.frame(
-                             terms = x$y,
-                             predictors = x$x,
+                             terms = unname(x$y),
+                             predictors = unname(x$x),
                              stringsAsFactors = FALSE
                            )
     )
@@ -313,9 +304,10 @@ tidy.step_impute_knn <- function(x, ...) {
 }
 
 #' @export
+#' @keywords internal
 tidy.step_knnimpute <- tidy.step_impute_knn
 
-#' @rdname tunable.step
+#' @rdname tunable.recipe
 #' @export
 tunable.step_impute_knn <- function(x, ...) {
   tibble::tibble(
@@ -328,4 +320,5 @@ tunable.step_impute_knn <- function(x, ...) {
 }
 
 #' @export
+#' @keywords internal
 tunable.step_knnimpute <- tunable.step_impute_knn
