@@ -5,12 +5,6 @@
 #'  range of values.
 #'
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables will be scaled. See [selections()] for more
-#'  details. For the `tidy` method, these are not currently
-#'  used.
-#' @param role Not used by this step since no new variables are
-#'  created.
 #' @param min A single numeric value for the smallest value in the
 #'  range.
 #' @param max A single numeric value for the largest value in the
@@ -19,18 +13,18 @@
 #'  normalized. Note that this is ignored until the values are
 #'  determined by [prep.recipe()]. Setting this value will
 #'  be ineffective.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  selectors or variables selected), `min`, and `max`.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept normalization_methods
+#' @template step-return
+#' @family normalization steps
 #' @export
 #' @details When a new data point is outside of the ranges seen in
 #'  the training set, the new values are truncated at `min` or
 #'  `max`.
+#'
+#'  When you [`tidy()`] this step, a tibble with columns `terms` (the
+#'  selectors or variables selected), `min`, and `max` is returned.
+#'
 #' @examples
+#' library(modeldata)
 #' data(biomass)
 #'
 #' biomass_tr <- biomass[biomass$dataset == "Training",]
@@ -94,7 +88,7 @@ step_range_new <-
 
 #' @export
 prep.step_range <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names])
 
   mins <-
@@ -124,8 +118,7 @@ bake.step_range <- function(object, new_data, ...) {
   tmp[tmp < object$min] <- object$min
   tmp[tmp > object$max] <- object$max
 
-  if (is.matrix(tmp) && ncol(tmp) == 1)
-    tmp <- tmp[, 1]
+  tmp <- tibble::as_tibble(tmp)
   new_data[, colnames(object$ranges)] <- tmp
   as_tibble(new_data)
 }
@@ -137,8 +130,7 @@ print.step_range <-
     invisible(x)
   }
 
-#' @rdname step_range
-#' @param x A `step_range` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_range <- function(x, ...) {
   if (is_trained(x)) {
