@@ -2,9 +2,6 @@ library(testthat)
 library(recipes)
 library(dplyr)
 
-context("Down-sampling")
-
-
 iris2 <- iris[-(1:45),]
 iris2$Species[seq(6, 96, by = 5)] <- NA
 iris2$Species2 <- sample(iris2$Species)
@@ -13,6 +10,7 @@ iris2$Species3 <- as.character(sample(iris2$Species))
 rec <- recipe( ~ ., data = iris2)
 
 test_that('basic usage', {
+  skip_if(utils::packageVersion("recipes") > "0.1.13")
   rec1 <- rec %>%
     step_downsample(tidyselect::matches("Species$"), id = "")
 
@@ -23,7 +21,7 @@ test_that('basic usage', {
 
   expect_equivalent(untrained, tidy(rec1, number = 1))
 
-  rec1_p <- prep(rec1, training = iris2, retain = TRUE)
+  rec1_p <- prep(rec1, training = iris2)
 
   trained <- tibble(
     terms = "Species",
@@ -45,10 +43,11 @@ test_that('basic usage', {
 })
 
 test_that('ratio value', {
+  skip_if(utils::packageVersion("recipes") > "0.1.13")
   rec2 <- rec %>%
     step_downsample(tidyselect::matches("Species$"), under_ratio = 2)
 
-  rec2_p <- prep(rec2, training = iris2, retain = TRUE)
+  rec2_p <- prep(rec2, training = iris2)
 
   tr_xtab <- table(juice(rec2_p)$Species, useNA = "always")
   te_xtab <- table(bake(rec2_p, new_data = iris2)$Species, useNA = "always")
@@ -61,10 +60,11 @@ test_that('ratio value', {
 
 
 test_that('no skipping', {
+  skip_if(utils::packageVersion("recipes") > "0.1.13")
   rec3 <- rec %>%
     step_downsample(tidyselect::matches("Species$"), skip = FALSE)
 
-  rec3_p <- prep(rec3, training = iris2, retain = TRUE)
+  rec3_p <- prep(rec3, training = iris2)
 
   tr_xtab <- table(juice(rec3_p)$Species, useNA = "always")
   te_xtab <- table(bake(rec3_p, new_data = iris2)$Species, useNA = "always")
@@ -77,6 +77,7 @@ test_that('no skipping', {
 
 
 test_that('bad data', {
+  skip_if(utils::packageVersion("recipes") > "0.1.13")
   expect_error(
     rec %>%
       step_downsample(Sepal.Width) %>%
@@ -85,29 +86,31 @@ test_that('bad data', {
   expect_error(
     rec %>%
       step_downsample(Species3) %>%
-      prep(strings_as_factors = FALSE, retain = TRUE)
+      prep(strings_as_factors = FALSE)
   )
   expect_error(
     rec %>%
       step_downsample(Species, Species2) %>%
-      prep(strings_as_factors = FALSE, retain = TRUE)
+      prep(strings_as_factors = FALSE)
   )
 })
 
 test_that('printing', {
+  skip_if(utils::packageVersion("recipes") > "0.1.13")
   rec4 <- rec %>%
     step_downsample(Species)
 
   expect_output(print(rec))
-  expect_output(prep(rec4, training = iris2, retain = TRUE, verbose = TRUE))
+  expect_output(prep(rec4, training = iris2, verbose = TRUE))
 })
 
 test_that('`seed` produces identical sampling', {
+  skip_if(utils::packageVersion("recipes") > "0.1.13")
 
   downsample_with_seed <- function(rec, seed = sample.int(10^5, 1)) {
     rec %>%
       step_downsample(Species, seed = seed) %>%
-      prep(training = iris2, retain = TRUE) %>%
+      prep(training = iris2) %>%
       juice() %>%
       pull(Petal.Width)
   }
@@ -122,6 +125,7 @@ test_that('`seed` produces identical sampling', {
 
 
 test_that('ratio deprecation', {
+  skip_if(utils::packageVersion("recipes") > "0.1.13")
 
   expect_message(
     new_rec <-
@@ -135,6 +139,7 @@ test_that('ratio deprecation', {
 
 
 test_that('tunable', {
+  skip_if(utils::packageVersion("recipes") > "0.1.13")
   rec <-
     recipe(~ ., data = iris) %>%
     step_downsample(all_predictors(), under_ratio = 1)
