@@ -4,10 +4,6 @@ library(dplyr)
 
 # ------------------------------------------------------------------------------
 
-context("dplyr mutate steps")
-
-# ------------------------------------------------------------------------------
-
 iris_rec <- recipe( ~ ., data = iris)
 
 # ------------------------------------------------------------------------------
@@ -20,7 +16,7 @@ test_that('basic usage', {
       half_length = Sepal.Length / 2
     )
 
-  prepped <- prep(rec, training = iris %>% slice(1:75), retain = TRUE)
+  prepped <- prep(rec, training = iris %>% slice(1:75))
 
   dplyr_train <-
     iris %>%
@@ -52,7 +48,7 @@ test_that('quasiquotation', {
     iris_rec %>%
     step_mutate(new_var = Sepal.Width * const)
 
-  prepped_1 <- prep(rec_1, training = iris %>% slice(1:75), retain = TRUE)
+  prepped_1 <- prep(rec_1, training = iris %>% slice(1:75))
 
   dplyr_train <-
     iris %>%
@@ -67,23 +63,43 @@ test_that('quasiquotation', {
     iris_rec %>%
     step_mutate(new_var = Sepal.Width * !!const)
 
-  prepped_2 <- prep(rec_2, training = iris %>% slice(1:75), retain = TRUE)
+  prepped_2 <- prep(rec_2, training = iris %>% slice(1:75))
 
   rm(const)
-  expect_error(prep(rec_1, training = iris %>% slice(1:75), retain = TRUE))
+  expect_error(prep(rec_1, training = iris %>% slice(1:75)))
   expect_error(
-    prepped_2 <- prep(rec_2, training = iris %>% slice(1:75), retain = TRUE),
+    prepped_2 <- prep(rec_2, training = iris %>% slice(1:75)),
     regexp = NA
   )
   rec_2_train <- juice(prepped_2)
   expect_equal(dplyr_train, rec_2_train)
 })
 
+test_that("can use unnamed expressions like `across()` (#759)", {
+  skip_if_not_installed("dplyr", "1.0.0")
+
+  df <- tibble(
+    x = c(TRUE, FALSE),
+    y = c(1, 2),
+    z = c(TRUE, FALSE)
+  )
+
+  rec <- recipe(~., df) %>%
+    step_mutate(across(where(is.logical), as.integer))
+
+  rec <- prep(rec, df)
+
+  expect_identical(
+    bake(rec, new_data = NULL),
+    mutate(df, across(where(is.logical), as.integer))
+  )
+})
+
 test_that('no input', {
   no_inputs <-
     iris_rec %>%
     step_mutate() %>%
-    prep(training = iris, retain = TRUE) %>%
+    prep(training = iris) %>%
     juice(composition = "data.frame")
   expect_equal(no_inputs, iris)
 })
@@ -94,9 +110,21 @@ test_that('printing', {
   expect_output(prep(rec, training = iris, verbose = TRUE))
 })
 
-# ------------------------------------------------------------------------------
+test_that("tidying allows for named and unnamed expressions", {
+  rec <- step_mutate(iris_rec, x = mean(y), id = "named")
+  tidied <- tidy(rec, id = "named")
 
-context("dplyr mutate_at steps")
+  # Named expressions use the name
+  expect_identical(tidied$terms, "x")
+  expect_identical(tidied$value, "mean(y)")
+
+  rec <- step_mutate(iris_rec, across(c(x, y), mean), id = "unnamed")
+  tidied <- tidy(rec, id = "unnamed")
+
+  # Unnamed expressions use the expression
+  expect_identical(tidied$terms, "across(c(x, y), mean)")
+  expect_identical(tidied$value, "across(c(x, y), mean)")
+})
 
 # ------------------------------------------------------------------------------
 
@@ -105,7 +133,7 @@ test_that('basic usage', {
     iris_rec %>%
     step_mutate_at(contains("Length"), fn = log)
 
-  prepped <- prep(rec, training = iris %>% slice(1:75), retain = TRUE)
+  prepped <- prep(rec, training = iris %>% slice(1:75))
 
   dplyr_train <-
     iris %>%
@@ -136,7 +164,7 @@ test_that('mulitple functions', {
     iris_rec %>%
     step_mutate_at(contains("Length"), fn = list(a = log, b = sqrt))
 
-  prepped <- prep(rec, training = iris %>% slice(1:75), retain = TRUE)
+  prepped <- prep(rec, training = iris %>% slice(1:75))
 
   dplyr_train <-
     iris %>%
@@ -171,7 +199,7 @@ test_that('no input', {
   expect_error(
     iris_rec %>%
       step_mutate_at() %>%
-      prep(training = iris, retain = TRUE) %>%
+      prep(training = iris) %>%
       juice(composition = "data.frame")
   )
 })
