@@ -1,9 +1,6 @@
 library(recipes)
 library(testthat)
 
-context("String to factor conversion")
-
-
 n <- 200
 
 set.seed(8575)
@@ -21,7 +18,7 @@ rec <- recipe(~ ., data = ex_dat)
 test_that('basic functionality', {
   ex_1 <- rec %>%
     step_string2factor(w, x) %>%
-    prep(ex_dat, strings_as_factors = FALSE, retain = TRUE) %>%
+    prep(ex_dat, strings_as_factors = FALSE) %>%
     juice
   expect_equal(class(ex_1$w), "factor")
   expect_equal(class(ex_1$x), "factor")
@@ -30,7 +27,7 @@ test_that('basic functionality', {
 
   ex_2 <- rec %>%
     step_string2factor(w, x, ordered = TRUE) %>%
-    prep(ex_dat, strings_as_factors = FALSE, retain = TRUE) %>%
+    prep(ex_dat, strings_as_factors = FALSE) %>%
     juice()
   expect_equal(class(ex_2$w), c("ordered", "factor"))
   expect_equal(class(ex_2$x), c("ordered", "factor"))
@@ -55,7 +52,7 @@ test_that('bad args', {
 test_that('printing', {
   ex_3 <- rec %>%
     step_string2factor(w, x) %>%
-    prep(ex_dat, strings_as_factors = FALSE, retain = TRUE)
+    prep(ex_dat, strings_as_factors = FALSE)
   expect_output(print(ex_3))
   expect_output(prep(ex_3, training = ex_dat, verbose = TRUE))
 })
@@ -63,7 +60,7 @@ test_that('printing', {
 test_that('pre-made factors', {
   ex_1 <- rec %>%
     step_string2factor(w, x, y, z) %>%
-    prep(ex_dat, strings_as_factors = FALSE, retain = TRUE) %>%
+    prep(ex_dat, strings_as_factors = FALSE) %>%
     juice()
   expect_true(inherits(ex_1$w, "factor"))
   expect_true(inherits(ex_1$x, "factor"))
